/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2019 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp19nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp19nid ;

DATA library.&dataset ;
INFILE datafile LRECL=3078;
INPUT
   ACCEPT  1-2              BUSCLAS  3-6             CANTPAY  7            
   CCULPSCO  8-9            CH2APP  10               CH8FINGD  11          
   CMSRVORD  12             COFI  13                 COMPLY  14            
   COMPLYPR  15             CRIMPURP  16             DETBFINE  17          
   DISPOSIT  18             EMPLOYNM  19             FCULPSCO  20-21       
   FRAUDTYP  22-23          FINSTDS  24              HISTORY  25           
   HSMISCND  26             INCORLOC  27             INCORPYR  28-31       
   INDICT  32               INPLEA1  33              INPLEA2  34           
   INPLEA3  35              INPLEA4  36              INPLEA5  37           
   INPLEA6  38              INPLEA7  39              INPLEA8  40           
   INPLEA9  41              INPLEA10  42             INPLEA11  43          
   INPLEA12  44             INNOPL1  45              INNOPL2  46           
   INNOPL3  47              INNOPL4  48              INNOPL5  49           
   INNOPL6  50              INNOPL7  51              INNOPL8  52           
   INNOPL9  53              INNOPL10  54             INNOPL11  55          
   INNOPL12  56             JANDC  57                NEWCNVTN  58          
   NOCOMP  59               NOCOUNTS  60-61          NOREAVAR  62          
   NOUSTAT  63-64           OBSTRUCT  65             OFFLVL  66-67         
   ORDERCE  68              ORGTYPE  69              OWNSTRCT  70-71       
   PLEA  72                 PRIMOFF  73-74           PRCIVIL  75           
   PRCRIME  76              PROBATN  77-78           PROBMON  79           
   PSR  80                  QUARTER  81              REAS1  82-85          
   REAS2  86-89             REAS3  90-91             REAS4  92-94          
   REAS5  95-97             REAS6  98-100            REASON2  101          
   REASON3  102             REASON4  103             REASONS  104          
   REMEDORD  105            SELFREP  106             SENTRNGE  107         
   SOURCES  108             TOLERNCE  109            TYPEOTHS  110-111     
   VICTNOTE  112            VIOLATE  113             AMENDYR  114-117      
   SENTYR  118-121          BASEFINE  122-130        COSTASSM  131-135     
   DISGORGE  136            FINOFFST  137-144        FORFEITR  145-154     
   GLFINMAX  155-163        GLFINMIN  164-172        STATMIN  173          
   STATMAX  174-183         RESTCAT  184             FINECAT  185          
   SUSFNCAT  186            LCAT1  187               LCAT2  188            
   LCATHI  189              LCATS1  190              LCATS2  191           
   LCATSHI  192             LCATR1  193              LCATR2  194           
   LCATRHI  195             LCATC1  196              LCATC2  197           
   LCATCHI  198             LCATU1  199              LCATU2  200           
   LCATUHI  201             CPIDN  202-208           BUSTEXT $ 209-252     
   FINSTXT $ 253-259        OWNSTEXT $ 260-281       PRMONTXT $ 282-362    
   ORDERTXT $ 363-554       TYPEOTTX $ 555-790       MINFINML  791-794     
   MAXFINML  795-797        ADJOFL1  798-799         ADJOFL2  800-801      
   ADJOFLHI  802-803        ADJ_B1  804-805          ADJ_B2  806           
   ADJ_BHI  807-808         ADJ_C1  809-810          ADJ_C2  811           
   ADJ_CHI  812-813         ADJ_D1  814              ADJ_D2  815           
   ADJ_DHI  816             ADJ_E1  817              ADJ_E2  818           
   ADJ_EHI  819             ADJ_F1  820              ADJ_F2  821           
   ADJ_FHI  822             ADJ_G1  823              ADJ_G2  824           
   ADJ_GHI  825             ADJ_H1  826              ADJ_H2  827           
   ADJ_HHI  828             ADJ_I1  829              ADJ_I2  830           
   ADJ_IHI  831             ADJ_J1  832              ADJ_J2  833           
   ADJ_JHI  834             ADJ_K1  835              ADJ_K2  836           
   ADJ_KHI  837             ADJ_L1  838              ADJ_L2  839           
   ADJ_LHI  840             ADJ_M1  841              ADJ_M2  842           
   ADJ_MHI  843             ADJ_N1  844              ADJ_N2  845           
   ADJ_NHI  846             ADJ_O1  847              ADJ_O2  848           
   ADJ_OHI  849             ADJ_P1  850              ADJ_P2  851           
   ADJ_PHI  852             ADJ_Q1  853              ADJ_Q2  854           
   ADJ_QHI  855             ADJ_R1  856              ADJ_R2  857           
   ADJ_RHI  858             ADJ_S1  859              ADJ_S2  860           
   ADJ_SHI  861             ADJ_T1  862              ADJ_T2  863           
   ADJ_THI  864             ADJ_U1  865              ADJ_U2  866           
   ADJ_UHI  867             BASADJ1  868-869         BASADJ2  870          
   BASADJHI  871-872        BASE1  873-874           BASE2  875-876        
   BASEHI  877-878          BASLN1  879              BASLN2  880           
   BASLNHI  881             ADJOFS1  882-883         ADJOFS2  884-885      
   ADJOFSHI  886-887        ADJS_B1  888-889         ADJS_B2  890          
   ADJS_BHI  891-892        ADJS_C1  893-894         ADJS_C2  895          
   ADJS_CHI  896-897        ADJS_D1  898             ADJS_D2  899          
   ADJS_DHI  900            ADJS_E1  901             ADJS_E2  902          
   ADJS_EHI  903            ADJS_F1  904             ADJS_F2  905          
   ADJS_FHI  906            ADJS_G1  907             ADJS_G2  908          
   ADJS_GHI  909            ADJS_H1  910             ADJS_H2  911          
   ADJS_HHI  912            ADJS_I1  913             ADJS_I2  914          
   ADJS_IHI  915            ADJS_J1  916             ADJS_J2  917          
   ADJS_JHI  918            ADJS_K1  919             ADJS_K2  920          
   ADJS_KHI  921            ADJS_L1  922             ADJS_L2  923          
   ADJS_LHI  924            ADJS_M1  925             ADJS_M2  926          
   ADJS_MHI  927            ADJS_N1  928             ADJS_N2  929          
   ADJS_NHI  930            ADJS_O1  931             ADJS_O2  932          
   ADJS_OHI  933            ADJS_P1  934             ADJS_P2  935          
   ADJS_PHI  936            ADJS_Q1  937             ADJS_Q2  938          
   ADJS_QHI  939            ADJS_R1  940             ADJS_R2  941          
   ADJS_RHI  942            ADJS_S1  943             ADJS_S2  944          
   ADJS_SHI  945            ADJS_T1  946             ADJS_T2  947          
   ADJS_THI  948            ADJS_U1  949             ADJS_U2  950          
   ADJS_UHI  951            BASADS1  952-953         BASADS2  954          
   BASADSHI  955-956        BASES1  957-958          BASES2  959-960       
   BASESHI  961-962         BASLNS1  963             BASLNS2  964          
   BASLNSHI  965            ADJOFR1  966-967         ADJOFR2  968-969      
   ADJOFRHI  970-971        ADJR_B1  972-973         ADJR_B2  974          
   ADJR_BHI  975-976        ADJR_C1  977             ADJR_C2  978          
   ADJR_CHI  979            ADJR_D1  980             ADJR_D2  981          
   ADJR_DHI  982            ADJR_E1  983             ADJR_E2  984          
   ADJR_EHI  985            ADJR_F1  986             ADJR_F2  987          
   ADJR_FHI  988            ADJR_G1  989             ADJR_G2  990          
   ADJR_GHI  991            ADJR_H1  992             ADJR_H2  993          
   ADJR_HHI  994            ADJR_I1  995             ADJR_I2  996          
   ADJR_IHI  997            ADJR_J1  998             ADJR_J2  999          
   ADJR_JHI  1000           ADJR_K1  1001            ADJR_K2  1002         
   ADJR_KHI  1003           ADJR_L1  1004            ADJR_L2  1005         
   ADJR_LHI  1006           ADJR_M1  1007            ADJR_M2  1008         
   ADJR_MHI  1009           ADJR_N1  1010            ADJR_N2  1011         
   ADJR_NHI  1012           ADJR_O1  1013            ADJR_O2  1014         
   ADJR_OHI  1015           ADJR_P1  1016            ADJR_P2  1017         
   ADJR_PHI  1018           ADJR_Q1  1019            ADJR_Q2  1020         
   ADJR_QHI  1021           ADJR_R1  1022            ADJR_R2  1023         
   ADJR_RHI  1024           ADJR_S1  1025            ADJR_S2  1026         
   ADJR_SHI  1027           ADJR_T1  1028            ADJR_T2  1029         
   ADJR_THI  1030           ADJR_U1  1031            ADJR_U2  1032         
   ADJR_UHI  1033           BASADR1  1034            BASADR2  1035         
   BASADRHI  1036           BASER1  1037             BASER2  1038-1039     
   BASERHI  1040-1041       BASLNR1  1042            BASLNR2  1043         
   BASLNRHI  1044           ADJOFC1  1045-1046       ADJOFC2  1047         
   ADJOFCHI  1048-1049      ADJC_B1  1050-1051       ADJC_B2  1052         
   ADJC_BHI  1053-1054      ADJC_C1  1055            ADJC_C2  1056         
   ADJC_CHI  1057           ADJC_D1  1058            ADJC_D2  1059         
   ADJC_DHI  1060           ADJC_E1  1061            ADJC_E2  1062         
   ADJC_EHI  1063           ADJC_F1  1064            ADJC_F2  1065         
   ADJC_FHI  1066           ADJC_G1  1067            ADJC_G2  1068         
   ADJC_GHI  1069           ADJC_H1  1070            ADJC_H2  1071         
   ADJC_HHI  1072           ADJC_I1  1073            ADJC_I2  1074         
   ADJC_IHI  1075           ADJC_J1  1076            ADJC_J2  1077         
   ADJC_JHI  1078           ADJC_K1  1079            ADJC_K2  1080         
   ADJC_KHI  1081           ADJC_L1  1082            ADJC_L2  1083         
   ADJC_LHI  1084           ADJC_M1  1085            ADJC_M2  1086         
   ADJC_MHI  1087           ADJC_N1  1088            ADJC_N2  1089         
   ADJC_NHI  1090           ADJC_O1  1091            ADJC_O2  1092         
   ADJC_OHI  1093           ADJC_P1  1094            ADJC_P2  1095         
   ADJC_PHI  1096           ADJC_Q1  1097            ADJC_Q2  1098         
   ADJC_QHI  1099           ADJC_R1  1100            ADJC_R2  1101         
   ADJC_RHI  1102           ADJC_S1  1103            ADJC_S2  1104         
   ADJC_SHI  1105           ADJC_T1  1106            ADJC_T2  1107         
   ADJC_THI  1108           ADJC_U1  1109            ADJC_U2  1110         
   ADJC_UHI  1111           BASADC1  1112            BASADC2  1113         
   BASADCHI  1114           BASEC1  1115             BASEC2  1116          
   BASECHI  1117            BASLNC1  1118            BASLNC2  1119         
   BASLNCHI  1120           ADJOFU1  1121            ADJOFU2  1122         
   ADJOFUHI  1123           ADJU_B1  1124            ADJU_B2  1125         
   ADJU_BHI  1126           ADJU_C1  1127            ADJU_C2  1128         
   ADJU_CHI  1129           ADJU_D1  1130            ADJU_D2  1131         
   ADJU_DHI  1132           ADJU_E1  1133            ADJU_E2  1134         
   ADJU_EHI  1135           ADJU_F1  1136            ADJU_F2  1137         
   ADJU_FHI  1138           ADJU_G1  1139            ADJU_G2  1140         
   ADJU_GHI  1141           ADJU_H1  1142            ADJU_H2  1143         
   ADJU_HHI  1144           ADJU_I1  1145            ADJU_I2  1146         
   ADJU_IHI  1147           ADJU_J1  1148            ADJU_J2  1149         
   ADJU_JHI  1150           ADJU_K1  1151            ADJU_K2  1152         
   ADJU_KHI  1153           ADJU_L1  1154            ADJU_L2  1155         
   ADJU_LHI  1156           ADJU_M1  1157            ADJU_M2  1158         
   ADJU_MHI  1159           ADJU_N1  1160            ADJU_N2  1161         
   ADJU_NHI  1162           ADJU_O1  1163            ADJU_O2  1164         
   ADJU_OHI  1165           ADJU_P1  1166            ADJU_P2  1167         
   ADJU_PHI  1168           ADJU_Q1  1169            ADJU_Q2  1170         
   ADJU_QHI  1171           ADJU_R1  1172            ADJU_R2  1173         
   ADJU_RHI  1174           ADJU_S1  1175            ADJU_S2  1176         
   ADJU_SHI  1177           ADJU_T1  1178            ADJU_T2  1179         
   ADJU_THI  1180           ADJU_U1  1181            ADJU_U2  1182         
   ADJU_UHI  1183           BASADU1  1184            BASADU2  1185         
   BASADUHI  1186           BASEU1  1187             BASEU2  1188          
   BASEUHI  1189            BASLNU1  1190            BASLNU2  1191         
   BASLNUHI  1192           ADJL_B1 $ 1193           ADJL_B2 $ 1194        
   ADJL_BHI $ 1195          ADJL_C1 $ 1196-1197      ADJL_C2 $ 1198        
   ADJL_CHI $ 1199-1200     ADJL_D1 $ 1201           ADJL_D2 $ 1202        
   ADJL_DHI $ 1203          ADJL_E1 $ 1204           ADJL_E2 $ 1205        
   ADJL_EHI $ 1206          ADJL_F1 $ 1207           ADJL_F2 $ 1208        
   ADJL_FHI $ 1209          ADJL_G1 $ 1210           ADJL_G2 $ 1211        
   ADJL_GHI $ 1212          ADJL_H1 $ 1213           ADJL_H2 $ 1214        
   ADJL_HHI $ 1215          ADJL_I1 $ 1216           ADJL_I2 $ 1217        
   ADJL_IHI $ 1218          ADJL_J1 $ 1219           ADJL_J2 $ 1220        
   ADJL_JHI $ 1221          ADJL_K1 $ 1222           ADJL_K2 $ 1223        
   ADJL_KHI $ 1224          ADJL_L1 $ 1225           ADJL_L2 $ 1226        
   ADJL_LHI $ 1227          ADJL_M1 $ 1228           ADJL_M2 $ 1229        
   ADJL_MHI $ 1230          ADJL_N1 $ 1231           ADJL_N2 $ 1232        
   ADJL_NHI $ 1233          ADJL_O1 $ 1234           ADJL_O2 $ 1235        
   ADJL_OHI $ 1236          ADJL_P1 $ 1237           ADJL_P2 $ 1238        
   ADJL_PHI $ 1239          ADJL_Q1 $ 1240           ADJL_Q2 $ 1241        
   ADJL_QHI $ 1242          ADJL_R1 $ 1243           ADJL_R2 $ 1244        
   ADJL_RHI $ 1245          ADJL_S1 $ 1246           ADJL_S2 $ 1247        
   ADJL_SHI $ 1248          ADJL_T1 $ 1249           ADJL_T2 $ 1250        
   ADJL_THI $ 1251          ADJL_U1 $ 1252           ADJL_U2 $ 1253        
   ADJL_UHI $ 1254          BASEL1 $ 1255            BASEL2 $ 1256         
   BASELHI $ 1257           ADSL_B1 $ 1258           ADSL_B2 $ 1259        
   ADSL_BHI $ 1260          ADSL_C1 $ 1261-1262      ADSL_C2 $ 1263        
   ADSL_CHI $ 1264-1265     ADSL_D1 $ 1266           ADSL_D2 $ 1267        
   ADSL_DHI $ 1268          ADSL_E1 $ 1269           ADSL_E2 $ 1270        
   ADSL_EHI $ 1271          ADSL_F1 $ 1272           ADSL_F2 $ 1273        
   ADSL_FHI $ 1274          ADSL_G1 $ 1275           ADSL_G2 $ 1276        
   ADSL_GHI $ 1277          ADSL_H1 $ 1278           ADSL_H2 $ 1279        
   ADSL_HHI $ 1280          ADSL_I1 $ 1281           ADSL_I2 $ 1282        
   ADSL_IHI $ 1283          ADSL_J1 $ 1284           ADSL_J2 $ 1285        
   ADSL_JHI $ 1286          ADSL_K1 $ 1287           ADSL_K2 $ 1288        
   ADSL_KHI $ 1289          ADSL_L1 $ 1290           ADSL_L2 $ 1291        
   ADSL_LHI $ 1292          ADSL_M1 $ 1293           ADSL_M2 $ 1294        
   ADSL_MHI $ 1295          ADSL_N1 $ 1296           ADSL_N2 $ 1297        
   ADSL_NHI $ 1298          ADSL_O1 $ 1299           ADSL_O2 $ 1300        
   ADSL_OHI $ 1301          ADSL_P1 $ 1302           ADSL_P2 $ 1303        
   ADSL_PHI $ 1304          ADSL_Q1 $ 1305           ADSL_Q2 $ 1306        
   ADSL_QHI $ 1307          ADSL_R1 $ 1308           ADSL_R2 $ 1309        
   ADSL_RHI $ 1310          ADSL_S1 $ 1311           ADSL_S2 $ 1312        
   ADSL_SHI $ 1313          ADSL_T1 $ 1314           ADSL_T2 $ 1315        
   ADSL_THI $ 1316          ADSL_U1 $ 1317           ADSL_U2 $ 1318        
   ADSL_UHI $ 1319          BASESL1 $ 1320           BASESL2 $ 1321        
   BASESLHI $ 1322          ADRL_B1 $ 1323           ADRL_B2 $ 1324        
   ADRL_BHI $ 1325          ADRL_C1 $ 1326-1327      ADRL_C2 $ 1328        
   ADRL_CHI $ 1329-1330     ADRL_D1 $ 1331           ADRL_D2 $ 1332        
   ADRL_DHI $ 1333          ADRL_E1 $ 1334           ADRL_E2 $ 1335        
   ADRL_EHI $ 1336          ADRL_F1 $ 1337           ADRL_F2 $ 1338        
   ADRL_FHI $ 1339          ADRL_G1 $ 1340           ADRL_G2 $ 1341        
   ADRL_GHI $ 1342          ADRL_H1 $ 1343-1344      ADRL_H2 $ 1345        
   ADRL_HHI $ 1346-1347     ADRL_I1 $ 1348           ADRL_I2 $ 1349        
   ADRL_IHI $ 1350          ADRL_J1 $ 1351           ADRL_J2 $ 1352        
   ADRL_JHI $ 1353          ADRL_K1 $ 1354           ADRL_K2 $ 1355        
   ADRL_KHI $ 1356          ADRL_L1 $ 1357           ADRL_L2 $ 1358        
   ADRL_LHI $ 1359          ADRL_M1 $ 1360           ADRL_M2 $ 1361        
   ADRL_MHI $ 1362          ADRL_N1 $ 1363           ADRL_N2 $ 1364        
   ADRL_NHI $ 1365          ADRL_O1 $ 1366           ADRL_O2 $ 1367        
   ADRL_OHI $ 1368          ADRL_P1 $ 1369           ADRL_P2 $ 1370        
   ADRL_PHI $ 1371          ADRL_Q1 $ 1372           ADRL_Q2 $ 1373        
   ADRL_QHI $ 1374          ADRL_R1 $ 1375           ADRL_R2 $ 1376        
   ADRL_RHI $ 1377          ADRL_S1 $ 1378           ADRL_S2 $ 1379        
   ADRL_SHI $ 1380          ADRL_T1 $ 1381           ADRL_T2 $ 1382        
   ADRL_THI $ 1383          ADRL_U1 $ 1384           ADRL_U2 $ 1385        
   ADRL_UHI $ 1386          BASERL1 $ 1387           BASERL2 $ 1388        
   BASERLHI $ 1389          ADCL_B1 $ 1390           ADCL_B2 $ 1391        
   ADCL_BHI $ 1392          ADCL_C1 $ 1393           ADCL_C2 $ 1394        
   ADCL_CHI $ 1395          ADCL_D1 $ 1396           ADCL_D2 $ 1397        
   ADCL_DHI $ 1398          ADCL_E1 $ 1399           ADCL_E2 $ 1400        
   ADCL_EHI $ 1401          ADCL_F1 $ 1402           ADCL_F2 $ 1403        
   ADCL_FHI $ 1404          ADCL_G1 $ 1405           ADCL_G2 $ 1406        
   ADCL_GHI $ 1407          ADCL_H1 $ 1408           ADCL_H2 $ 1409        
   ADCL_HHI $ 1410          ADCL_I1 $ 1411           ADCL_I2 $ 1412        
   ADCL_IHI $ 1413          ADCL_J1 $ 1414           ADCL_J2 $ 1415        
   ADCL_JHI $ 1416          ADCL_K1 $ 1417           ADCL_K2 $ 1418        
   ADCL_KHI $ 1419          ADCL_L1 $ 1420           ADCL_L2 $ 1421        
   ADCL_LHI $ 1422          ADCL_M1 $ 1423           ADCL_M2 $ 1424        
   ADCL_MHI $ 1425          ADCL_N1 $ 1426           ADCL_N2 $ 1427        
   ADCL_NHI $ 1428          ADCL_O1 $ 1429           ADCL_O2 $ 1430        
   ADCL_OHI $ 1431          ADCL_P1 $ 1432           ADCL_P2 $ 1433        
   ADCL_PHI $ 1434          ADCL_Q1 $ 1435           ADCL_Q2 $ 1436        
   ADCL_QHI $ 1437          ADCL_R1 $ 1438           ADCL_R2 $ 1439        
   ADCL_RHI $ 1440          ADCL_S1 $ 1441           ADCL_S2 $ 1442        
   ADCL_SHI $ 1443          ADCL_T1 $ 1444           ADCL_T2 $ 1445        
   ADCL_THI $ 1446          ADCL_U1 $ 1447           ADCL_U2 $ 1448        
   ADCL_UHI $ 1449          BASECL1 $ 1450           BASECL2 $ 1451        
   BASECLHI $ 1452          ADUL_B1 $ 1453           ADUL_B2 $ 1454        
   ADUL_BHI $ 1455          ADUL_C1 $ 1456           ADUL_C2 $ 1457        
   ADUL_CHI $ 1458          ADUL_D1 $ 1459           ADUL_D2 $ 1460        
   ADUL_DHI $ 1461          ADUL_E1 $ 1462           ADUL_E2 $ 1463        
   ADUL_EHI $ 1464          ADUL_F1 $ 1465           ADUL_F2 $ 1466        
   ADUL_FHI $ 1467          ADUL_G1 $ 1468           ADUL_G2 $ 1469        
   ADUL_GHI $ 1470          ADUL_H1 $ 1471           ADUL_H2 $ 1472        
   ADUL_HHI $ 1473          ADUL_I1 $ 1474           ADUL_I2 $ 1475        
   ADUL_IHI $ 1476          ADUL_J1 $ 1477           ADUL_J2 $ 1478        
   ADUL_JHI $ 1479          ADUL_K1 $ 1480           ADUL_K2 $ 1481        
   ADUL_KHI $ 1482          ADUL_L1 $ 1483           ADUL_L2 $ 1484        
   ADUL_LHI $ 1485          ADUL_M1 $ 1486           ADUL_M2 $ 1487        
   ADUL_MHI $ 1488          ADUL_N1 $ 1489           ADUL_N2 $ 1490        
   ADUL_NHI $ 1491          ADUL_O1 $ 1492           ADUL_O2 $ 1493        
   ADUL_OHI $ 1494          ADUL_P1 $ 1495           ADUL_P2 $ 1496        
   ADUL_PHI $ 1497          ADUL_Q1 $ 1498           ADUL_Q2 $ 1499        
   ADUL_QHI $ 1500          ADUL_R1 $ 1501           ADUL_R2 $ 1502        
   ADUL_RHI $ 1503          ADUL_S1 $ 1504           ADUL_S2 $ 1505        
   ADUL_SHI $ 1506          ADUL_T1 $ 1507           ADUL_T2 $ 1508        
   ADUL_THI $ 1509          ADUL_U1 $ 1510           ADUL_U2 $ 1511        
   ADUL_UHI $ 1512          BASEUL1 $ 1513           BASEUL2 $ 1514        
   BASEULHI $ 1515          GDLINE1 $ 1516-1520      GDLINE2 $ 1521-1525   
   GDSTAT1 $ 1526-1530      GDSTAT2 $ 1531-1535      GDREF1 $ 1536-1540    
   GDREF2 $ 1541-1545       GDCROS1 $ 1546-1550      GDCROS2 $ 1551        
   GDUNDR1 $ 1552           GDUNDR2 $ 1553           GDLINEHI $ 1554-1558  
   GDSTATHI $ 1559-1563     GDREFHI $ 1564-1568      GDCROSHI $ 1569-1573  
   GDUNDRHI $ 1574          STA1_1 $ 1575-1585       STA1_2 $ 1586-1594    
   STA1_3 $ 1595-1605       STA1_4 $ 1606-1616       STA1_5 $ 1617-1627    
   STA1_6 $ 1628-1636       STA1_7 $ 1637-1645       STA1_8 $ 1646-1654    
   STA1_9 $ 1655-1661       STA1_10 $ 1662-1668      STA1_11 $ 1669-1675   
   STA1_12 $ 1676-1682      STA1_13 $ 1683-1692      STA1_14 $ 1693-1699   
   STA1_15 $ 1700-1706      STA1_16 $ 1707-1713      STA1_17 $ 1714-1720   
   STA1_18 $ 1721-1726      STA1_19 $ 1727-1732      STA1_20 $ 1733-1738   
   STA1_21 $ 1739-1744      STA1_22 $ 1745-1750      STA1_23 $ 1751-1756   
   STA1_24 $ 1757-1762      STA1_25 $ 1763-1768      STA1_26 $ 1769-1774   
   STA1_27 $ 1775-1780      STA1_28 $ 1781-1786      STA1_29 $ 1787-1792   
   STA1_30 $ 1793-1798      STA1_31 $ 1799-1804      STA1_32 $ 1805-1810   
   STA1_33 $ 1811-1816      STA1_34 $ 1817-1822      STA1_35 $ 1823-1828   
   STA1_36 $ 1829-1834      STA1_37 $ 1835-1840      STA1_38 $ 1841-1846   
   STA1_39 $ 1847-1852      STA1_40 $ 1853-1858      STA1_41 $ 1859-1864   
   STA1_42 $ 1865-1870      STA1_43 $ 1871-1876      STA1_44 $ 1877-1882   
   STA1_45 $ 1883-1888      STA1_46 $ 1889-1894      STA1_47 $ 1895-1900   
   STA1_48 $ 1901-1906      STA1_49 $ 1907-1912      STA1_50 $ 1913-1918   
   STA1_51 $ 1919-1924      STA1_52 $ 1925-1930      STA1_53 $ 1931-1935   
   STA1_54 $ 1936-1942      STA1_55 $ 1943-1947      STA1_56 $ 1948-1955   
   STA1_57 $ 1956-1963      STA1_58 $ 1964-1969      STA1_59 $ 1970-1975   
   STA1_60 $ 1976-1982      STA1_61 $ 1983-1989      STA1_62 $ 1990-1997   
   STA1_63 $ 1998-2003      STA1_64 $ 2004-2010      STA2_1 $ 2011-2019    
   STA2_2 $ 2020-2027       STA2_3 $ 2028-2035       STA2_4 $ 2036-2043    
   STA2_5 $ 2044-2051       STA2_6 $ 2052-2059       STA2_7 $ 2060-2067    
   STA2_8 $ 2068-2075       STA2_9 $ 2076-2079       STA2_10 $ 2080-2083   
   STA2_11 $ 2084-2087      STA2_12 $ 2088-2091      STA2_13 $ 2092-2095   
   STA2_14 $ 2096-2099      STA2_15 $ 2100           STA2_16 $ 2101        
   STA2_17 $ 2102           STA2_18 $ 2103           STA2_19 $ 2104        
   STA2_20 $ 2105           STA2_21 $ 2106           STA2_22 $ 2107        
   STA2_23 $ 2108           STA2_24 $ 2109-2114      STA2_25 $ 2115-2120   
   STA2_26 $ 2121-2126      STA2_27 $ 2127-2132      STA2_28 $ 2133-2138   
   STA2_29 $ 2139-2144      STA2_30 $ 2145-2150      STA2_31 $ 2151-2156   
   STA2_32 $ 2157-2162      STA2_33 $ 2163-2168      STA2_34 $ 2169-2174   
   STA2_35 $ 2175-2180      STA2_36 $ 2181-2186      STA2_37 $ 2187-2192   
   STA2_38 $ 2193-2198      STA2_39 $ 2199-2204      STA2_40 $ 2205-2210   
   STA2_41 $ 2211-2216      STA2_42 $ 2217-2222      STA2_43 $ 2223-2228   
   STA2_44 $ 2229-2234      STA2_45 $ 2235-2240      STA2_46 $ 2241-2246   
   STA2_47 $ 2247-2252      STA2_48 $ 2253-2258      STA2_49 $ 2259-2264   
   STA2_50 $ 2265-2270      STA2_51 $ 2271-2276      STA2_52 $ 2277-2282   
   STA2_53 $ 2283-2285      STA2_54 $ 2286           STA2_55 $ 2287        
   STA2_56 $ 2288-2295      STA2_57 $ 2296-2303      STA2_58 $ 2304-2306   
   STA2_59 $ 2307-2309      STA2_60 $ 2310-2316      STA2_61 $ 2317-2323   
   STA2_62 $ 2324-2326      STA2_63 $ 2327-2329      STA2_64 $ 2330-2336   
   STA3_1 $ 2337-2344       STA3_2 $ 2345-2352       STA3_3 $ 2353-2360    
   STA3_4 $ 2361-2368       STA3_5 $ 2369-2376       STA3_6 $ 2377         
   STA3_7 $ 2378            STA3_8 $ 2379            STA3_9 $ 2380         
   STA3_10 $ 2381           STA3_11 $ 2382           STA3_12 $ 2383        
   STA3_13 $ 2384           STA3_14 $ 2385           STA3_15 $ 2386        
   STA3_16 $ 2387           STA3_17 $ 2388           STA3_18 $ 2389        
   STA3_19 $ 2390           STA3_20 $ 2391           STA3_21 $ 2392        
   STA3_22 $ 2393           STA3_23 $ 2394           STA3_24 $ 2395        
   STA3_25 $ 2396           STA3_26 $ 2397           STA3_27 $ 2398        
   STA3_28 $ 2399           STA3_29 $ 2400           STA3_30 $ 2401        
   STA3_31 $ 2402           STA3_32 $ 2403           STA3_33 $ 2404        
   STA3_34 $ 2405           STA3_35 $ 2406           STA3_36 $ 2407        
   STA3_37 $ 2408           STA3_38 $ 2409           STA3_39 $ 2410        
   STA3_40 $ 2411           STA3_41 $ 2412           STA3_42 $ 2413        
   STA3_43 $ 2414           STA3_44 $ 2415           STA3_45 $ 2416        
   STA3_46 $ 2417           STA3_47 $ 2418           STA3_48 $ 2419        
   STA3_49 $ 2420           STA3_50 $ 2421           STA3_51 $ 2422        
   STA3_52 $ 2423           STA3_53 $ 2424           STA3_54 $ 2425        
   STA3_55 $ 2426           STA3_56 $ 2427           STA3_57 $ 2428        
   STA3_58 $ 2429           STA3_59 $ 2430           STA3_60 $ 2431-2438   
   STA3_61 $ 2439-2446      STA3_62 $ 2447           STA3_63 $ 2448        
   STA3_64 $ 2449-2456      NWSTAT1 $ 2457-2467      NWSTAT2 $ 2468-2478   
   NWSTAT3 $ 2479-2488      NWSTAT4 $ 2489-2495      NWSTAT5 $ 2496-2503   
   NWSTAT6 $ 2504-2511      NWSTAT7 $ 2512-2519      NWSTAT8 $ 2520-2527   
   NWSTAT9 $ 2528-2535      NWSTAT10 $ 2536-2540     NWSTAT11 $ 2541-2548  
   NWSTAT12 $ 2549-2555     NWSTAT13 $ 2556-2563     SMAX1  2564-2573      
   SMAX2  2574-2580         SMAX3  2581-2587         SMAX4  2588-2594      
   SMAX5  2595-2601         SMAX6  2602-2607         SMAX7  2608-2613      
   SMAX8  2614-2619         SMAX9  2620-2625         SMAX10  2626-2631     
   SMAX11  2632-2637        SMAX12  2638-2643        SMAX13  2644-2650     
   SMAX14  2651-2656        SMAX15  2657-2662        SMAX16  2663-2668     
   SMAX17  2669-2674        SMAX18  2675-2680        SMAX19  2681-2686     
   SMAX20  2687-2692        SMAX21  2693-2698        SMAX22  2699-2704     
   SMAX23  2705-2710        SMAX24  2711-2716        SMAX25  2717-2722     
   SMAX26  2723-2728        SMAX27  2729-2734        SMAX28  2735-2740     
   SMAX29  2741-2746        SMAX30  2747-2752        SMAX31  2753-2758     
   SMAX32  2759-2764        SMAX33  2765-2770        SMAX34  2771-2776     
   SMAX35  2777-2782        SMAX36  2783-2788        SMAX37  2789-2794     
   SMAX38  2795-2800        SMAX39  2801-2806        SMAX40  2807-2812     
   SMAX41  2813-2818        SMAX42  2819-2824        SMAX43  2825-2830     
   SMAX44  2831-2836        SMAX45  2837-2842        SMAX46  2843-2848     
   SMAX47  2849-2854        SMAX48  2855-2860        SMAX49  2861-2866     
   SMAX50  2867-2872        SMAX51  2873-2878        SMAX52  2879-2884     
   SMAX53  2885-2890        SMAX54  2891-2896        SMAX55  2897-2902     
   SMAX56  2903-2908        SMAX57  2909-2914        SMAX58  2915-2920     
   SMAX59  2921-2926        SMAX60  2927-2932        SMAX61  2933-2938     
   SMAX62  2939-2944        SMAX63  2945-2950        SMAX64  2951-2956     
   SMIN1  2957              SMIN2  2958              SMIN3  2959           
   SMIN4  2960              SMIN5  2961              SMIN6  2962           
   SMIN7  2963              SMIN8  2964              SMIN9  2965           
   SMIN10  2966             SMIN11  2967             SMIN12  2968          
   SMIN13  2969             SMIN14  2970             SMIN15  2971          
   SMIN16  2972             SMIN17  2973             SMIN18  2974          
   SMIN19  2975             SMIN20  2976             SMIN21  2977          
   SMIN22  2978             SMIN23  2979             SMIN24  2980          
   SMIN25  2981             SMIN26  2982             SMIN27  2983          
   SMIN28  2984             SMIN29  2985             SMIN30  2986          
   SMIN31  2987             SMIN32  2988             SMIN33  2989          
   SMIN34  2990             SMIN35  2991             SMIN36  2992          
   SMIN37  2993             SMIN38  2994             SMIN39  2995          
   SMIN40  2996             SMIN41  2997             SMIN42  2998          
   SMIN43  2999             SMIN44  3000             SMIN45  3001          
   SMIN46  3002             SMIN47  3003             SMIN48  3004          
   SMIN49  3005             SMIN50  3006             SMIN51  3007          
   SMIN52  3008             SMIN53  3009             SMIN54  3010          
   SMIN55  3011             SMIN56  3012             SMIN57  3013          
   SMIN58  3014             SMIN59  3015             SMIN60  3016          
   SMIN61  3017             SMIN62  3018             SMIN63  3019          
   SMIN64  3020             RETEXT1 $ 3021-3073      RETEXT2 $ 3074        
   RETEXT3 $ 3075           RETEXT4 $ 3076           RETEXT5 $ 3077        
   RETEXT6 $ 3078         ;                       

LENGTH
   ACCEPT 3                 BUSCLAS 4                CANTPAY 3             
   CCULPSCO 3               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COFI 3                   COMPLY 3              
   COMPLYPR 3               CRIMPURP 3               DETBFINE 3            
   DISPOSIT 3               EMPLOYNM 3               FCULPSCO 3            
   FRAUDTYP 3               FINSTDS 3                HISTORY 3             
   HSMISCND 3               INCORLOC 3               INCORPYR 4            
   INDICT 3                 INPLEA1 3                INPLEA2 3             
   INPLEA3 3                INPLEA4 3                INPLEA5 3             
   INPLEA6 3                INPLEA7 3                INPLEA8 3             
   INPLEA9 3                INPLEA10 3               INPLEA11 3            
   INPLEA12 3               INNOPL1 3                INNOPL2 3             
   INNOPL3 3                INNOPL4 3                INNOPL5 3             
   INNOPL6 3                INNOPL7 3                INNOPL8 3             
   INNOPL9 3                INNOPL10 3               INNOPL11 3            
   INNOPL12 3               JANDC 3                  NEWCNVTN 3            
   NOCOMP 3                 NOCOUNTS 3               NOREAVAR 3            
   NOUSTAT 3                OBSTRUCT 3               OFFLVL 3              
   ORDERCE 3                ORGTYPE 3                OWNSTRCT 3            
   PLEA 3                   PRIMOFF 3                PRCIVIL 3             
   PRCRIME 3                PROBATN 3                PROBMON 3             
   PSR 3                    QUARTER 3                REAS1 4               
   REAS2 4                  REAS3 3                  REAS4 4               
   REAS5 4                  REAS6 4                  REASON2 3             
   REASON3 3                REASON4 3                REASONS 3             
   REMEDORD 3               SELFREP 3                SENTRNGE 3            
   SOURCES 3                TOLERNCE 3               TYPEOTHS 3            
   VICTNOTE 3               VIOLATE 3                AMENDYR 4             
   SENTYR 4                 BASEFINE 6               COSTASSM 4            
   DISGORGE 3               FINOFFST 6               GLFINMAX 6            
   GLFINMIN 6               STATMIN 3                STATMAX 6             
   RESTCAT 3                FINECAT 3                SUSFNCAT 3            
   LCAT1 3                  LCAT2 3                  LCATHI 3              
   LCATS1 3                 LCATS2 3                 LCATSHI 3             
   LCATR1 3                 LCATR2 3                 LCATRHI 3             
   LCATC1 3                 LCATC2 3                 LCATCHI 3             
   LCATU1 3                 LCATU2 3                 LCATUHI 3             
   CPIDN 6                  ADJOFL1 3                ADJOFL2 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_PHI 3                ADJ_Q1 3                 ADJ_Q2 3              
   ADJ_QHI 3                ADJ_R1 3                 ADJ_R2 3              
   ADJ_RHI 3                ADJ_S1 3                 ADJ_S2 3              
   ADJ_SHI 3                ADJ_T1 3                 ADJ_T2 3              
   ADJ_THI 3                ADJ_U1 3                 ADJ_U2 3              
   ADJ_UHI 3                BASADJ1 3                BASADJ2 3             
   BASADJHI 3               BASE1 3                  BASE2 3               
   BASEHI 3                 BASLN1 3                 BASLN2 3              
   BASLNHI 3                ADJOFS1 3                ADJOFS2 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_PHI 3               ADJS_Q1 3                ADJS_Q2 3             
   ADJS_QHI 3               ADJS_R1 3                ADJS_R2 3             
   ADJS_RHI 3               ADJS_S1 3                ADJS_S2 3             
   ADJS_SHI 3               ADJS_T1 3                ADJS_T2 3             
   ADJS_THI 3               ADJS_U1 3                ADJS_U2 3             
   ADJS_UHI 3               BASADS1 3                BASADS2 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASESHI 3                BASLNS1 3                BASLNS2 3             
   BASLNSHI 3               ADJOFR1 3                ADJOFR2 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_PHI 3               ADJR_Q1 3                ADJR_Q2 3             
   ADJR_QHI 3               ADJR_R1 3                ADJR_R2 3             
   ADJR_RHI 3               ADJR_S1 3                ADJR_S2 3             
   ADJR_SHI 3               ADJR_T1 3                ADJR_T2 3             
   ADJR_THI 3               ADJR_U1 3                ADJR_U2 3             
   ADJR_UHI 3               BASADR1 3                BASADR2 3             
   BASADRHI 3               BASER1 3                 BASER2 3              
   BASERHI 3                BASLNR1 3                BASLNR2 3             
   BASLNRHI 3               ADJOFC1 3                ADJOFC2 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_PHI 3               ADJC_Q1 3                ADJC_Q2 3             
   ADJC_QHI 3               ADJC_R1 3                ADJC_R2 3             
   ADJC_RHI 3               ADJC_S1 3                ADJC_S2 3             
   ADJC_SHI 3               ADJC_T1 3                ADJC_T2 3             
   ADJC_THI 3               ADJC_U1 3                ADJC_U2 3             
   ADJC_UHI 3               BASADC1 3                BASADC2 3             
   BASADCHI 3               BASEC1 3                 BASEC2 3              
   BASECHI 3                BASLNC1 3                BASLNC2 3             
   BASLNCHI 3               ADJOFU1 3                ADJOFU2 3             
   ADJOFUHI 3               ADJU_B1 3                ADJU_B2 3             
   ADJU_BHI 3               ADJU_C1 3                ADJU_C2 3             
   ADJU_CHI 3               ADJU_D1 3                ADJU_D2 3             
   ADJU_DHI 3               ADJU_E1 3                ADJU_E2 3             
   ADJU_EHI 3               ADJU_F1 3                ADJU_F2 3             
   ADJU_FHI 3               ADJU_G1 3                ADJU_G2 3             
   ADJU_GHI 3               ADJU_H1 3                ADJU_H2 3             
   ADJU_HHI 3               ADJU_I1 3                ADJU_I2 3             
   ADJU_IHI 3               ADJU_J1 3                ADJU_J2 3             
   ADJU_JHI 3               ADJU_K1 3                ADJU_K2 3             
   ADJU_KHI 3               ADJU_L1 3                ADJU_L2 3             
   ADJU_LHI 3               ADJU_M1 3                ADJU_M2 3             
   ADJU_MHI 3               ADJU_N1 3                ADJU_N2 3             
   ADJU_NHI 3               ADJU_O1 3                ADJU_O2 3             
   ADJU_OHI 3               ADJU_P1 3                ADJU_P2 3             
   ADJU_PHI 3               ADJU_Q1 3                ADJU_Q2 3             
   ADJU_QHI 3               ADJU_R1 3                ADJU_R2 3             
   ADJU_RHI 3               ADJU_S1 3                ADJU_S2 3             
   ADJU_SHI 3               ADJU_T1 3                ADJU_T2 3             
   ADJU_THI 3               ADJU_U1 3                ADJU_U2 3             
   ADJU_UHI 3               BASADU1 3                BASADU2 3             
   BASADUHI 3               BASEU1 3                 BASEU2 3              
   BASEUHI 3                BASLNU1 3                BASLNU2 3             
   BASLNUHI 3               SMAX1 6                  SMAX2 6               
   SMAX3 6                  SMAX4 6                  SMAX5 6               
   SMAX6 6                  SMAX7 6                  SMAX8 6               
   SMAX9 6                  SMAX10 6                 SMAX11 6              
   SMAX12 6                 SMAX13 6                 SMAX14 6              
   SMAX15 6                 SMAX16 6                 SMAX17 6              
   SMAX18 6                 SMAX19 6                 SMAX20 6              
   SMAX21 6                 SMAX22 6                 SMAX23 6              
   SMAX24 6                 SMAX25 6                 SMAX26 6              
   SMAX27 6                 SMAX28 6                 SMAX29 6              
   SMAX30 6                 SMAX31 6                 SMAX32 6              
   SMAX33 6                 SMAX34 6                 SMAX35 6              
   SMAX36 6                 SMAX37 6                 SMAX38 6              
   SMAX39 6                 SMAX40 6                 SMAX41 6              
   SMAX42 6                 SMAX43 6                 SMAX44 6              
   SMAX45 6                 SMAX46 6                 SMAX47 6              
   SMAX48 6                 SMAX49 6                 SMAX50 6              
   SMAX51 6                 SMAX52 6                 SMAX53 6              
   SMAX54 6                 SMAX55 6                 SMAX56 6              
   SMAX57 6                 SMAX58 6                 SMAX59 6              
   SMAX60 6                 SMAX61 6                 SMAX62 6              
   SMAX63 6                 SMAX64 6                 SMIN1 3               
   SMIN2 3                  SMIN3 3                  SMIN4 3               
   SMIN5 3                  SMIN6 3                  SMIN7 3               
   SMIN8 3                  SMIN9 3                  SMIN10 3              
   SMIN11 3                 SMIN12 3                 SMIN13 3              
   SMIN14 3                 SMIN15 3                 SMIN16 3              
   SMIN17 3                 SMIN18 3                 SMIN19 3              
   SMIN20 3                 SMIN21 3                 SMIN22 3              
   SMIN23 3                 SMIN24 3                 SMIN25 3              
   SMIN26 3                 SMIN27 3                 SMIN28 3              
   SMIN29 3                 SMIN30 3                 SMIN31 3              
   SMIN32 3                 SMIN33 3                 SMIN34 3              
   SMIN35 3                 SMIN36 3                 SMIN37 3              
   SMIN38 3                 SMIN39 3                 SMIN40 3              
   SMIN41 3                 SMIN42 3                 SMIN43 3              
   SMIN44 3                 SMIN45 3                 SMIN46 3              
   SMIN47 3                 SMIN48 3                 SMIN49 3              
   SMIN50 3                 SMIN51 3                 SMIN52 3              
   SMIN53 3                 SMIN54 3                 SMIN55 3              
   SMIN56 3                 SMIN57 3                 SMIN58 3              
   SMIN59 3                 SMIN60 3                 SMIN61 3              
   SMIN62 3                 SMIN63 3                 SMIN64 3 ;

          

RUN ;
